TypedValue

Enum TypedValue 

#[repr(C)]
pub enum TypedValue { Unparsed(UnparsedValue), Keyword(KeywordValue), Numeric(NumericValue), Transform(TransformValue), Image(ImageValue), }
A property-agnostic representation of a value, used by Typed OM.

TypedValue is the internal counterpart of the various CSSStyleValue subclasses defined by the Typed OM specification. It captures values that can be represented independently of any particular property.

Variants



Unparsed(UnparsedValue)

An unparsed value consisting of string fragments and variable references.

This corresponds to CSSUnparsedValue in the Typed OM specification.



Keyword(KeywordValue)

A keyword value such as "block", "none", or "thin".

This corresponds to CSSKeywordValue in the Typed OM specification. Keywords are represented as a standalone KeywordValue so they can be carried and compared independently of any particular property.



Numeric(NumericValue)

A numeric value such as a length, angle, time, or a sum thereof.

This corresponds to the CSSNumericValue hierarchy in the Typed OM specification, including CSSUnitValue and CSSMathSum.



Transform(TransformValue)

A transform value such as translate(10px, 20px).

This corresponds to CSSTransformValue in the Typed OM specification.



Image(ImageValue)

An image value.

This corresponds to CSSImageValue in the Typed OM specification.