#[repr(C)]pub struct MathClamp {
pub numeric_type: NumericType,
pub values: OwnedArray<NumericValue, 3>,
}Expand description
A clamp expression over numeric values.
This corresponds to CSSMathClamp in the Typed OM specification. A clamp
expression represents constructs such as clamp(10px, 20%, 30px).
The array entries correspond to the lower bound, value, and upper bound, respectively.
Fields
numeric_type: NumericTypeThe numeric type associated with this clamp.
values: OwnedArray<NumericValue, 3>The lower bound, value, and upper bound of the clamp expression, in that order.
Implementations
Sourceimpl MathClamp
impl MathClamp
Sourcepub fn try_from_numeric_values(
values: OwnedArray<NumericValue, 3>,
) -> Result<Self, ()>
pub fn try_from_numeric_values( values: OwnedArray<NumericValue, 3>, ) -> Result<Self, ()>
Creates a math clamp from a sequence of numeric values.
Returns an error if the values do not have addable numeric types.