#[repr(C)]pub struct MathMax {
pub numeric_type: NumericType,
pub values: ThinVec<NumericValue>,
}Expand description
A maximum expression over numeric values.
This corresponds to CSSMathMax in the Typed OM specification. A maximum
expression represents constructs such as max(10px, 20%). Each entry is
itself a NumericValue, allowing nested math expressions if needed.
Fields
numeric_type: NumericTypeThe numeric type associated with this max.
values: ThinVec<NumericValue>The list of numeric terms that make up the max.
Implementations
Sourceimpl MathMax
impl MathMax
Sourcepub fn try_from_numeric_values(
values: ThinVec<NumericValue>,
) -> Result<Self, ()>
pub fn try_from_numeric_values( values: ThinVec<NumericValue>, ) -> Result<Self, ()>
Creates a math max from a sequence of numeric values.
Returns an error if the values do not have addable numeric types.