#[repr(C)]pub struct MathMin {
pub numeric_type: NumericType,
pub values: ThinVec<NumericValue>,
}Expand description
A minimum expression over numeric values.
This corresponds to CSSMathMin in the Typed OM specification. A minimum
expression represents constructs such as min(10px, 20%). Each entry is
itself a NumericValue, allowing nested math expressions if needed.
Fields
numeric_type: NumericTypeThe numeric type associated with this min.
values: ThinVec<NumericValue>The list of numeric terms that make up the min.
Implementations
Sourceimpl MathMin
impl MathMin
Sourcepub fn try_from_numeric_values(
values: ThinVec<NumericValue>,
) -> Result<Self, ()>
pub fn try_from_numeric_values( values: ThinVec<NumericValue>, ) -> Result<Self, ()>
Creates a math min from a sequence of numeric values.
Returns an error if the values do not have addable numeric types.