#[repr(C)]pub struct RotateComponent {
pub angle: NumericValue,
pub x: NumericValue,
pub y: NumericValue,
pub z: NumericValue,
pub is_2d: bool,
}Expand description
A rotate transform component used by the Typed OM.
This corresponds to CSSRotate in the Typed OM specification. The angle,
x, y, and z components are always present; omitted axis coordinates
are represented using the implicit axis for the corresponding rotate
function.
The is_2d flag indicates whether the component was reified from a 2D
rotate function.
Fields
angle: NumericValueThe rotation angle.
x: NumericValueThe x-axis rotation coordinate.
y: NumericValueThe y-axis rotation coordinate.
z: NumericValueThe z-axis rotation coordinate.
is_2d: boolWhether this rotate component is two-dimensional.