#[repr(C)]pub struct TranslateComponent {
pub x: NumericValue,
pub y: NumericValue,
pub z: NumericValue,
pub is_2d: bool,
}Expand description
A translate transform component used by the Typed OM.
This corresponds to CSSTranslate in the Typed OM specification. The x,
y, and z components are always present; omitted offsets are represented
as 0px.
The is_2d flag indicates whether the component was reified from a 2D
translate function.
Fields
x: NumericValueThe x-axis translation component.
y: NumericValueThe y-axis translation component.
z: NumericValueThe z-axis translation component.
is_2d: boolWhether this translate component is two-dimensional.